<?php

/**
 * @file
 * Definition of CharacterController.
 */

/**
 * Controller class for characters.
 *
 * This extends the EntityAPIController class, adding required special handling
 * for character objects.
 */
class WoWCharacterController extends EntityAPIController {

  /**
   * Load a character from the database.
   * @see DrupalDefaultEntityController::attachLoad()
   */
  public function attachLoad(&$characters, $revision_id = FALSE) {
    // Get the entity refresh method.
    $refresh = variable_get('wow_character_refresh_method');

    if ($refresh == WOW_REFRESH_LOAD) {
      // Get the threshold value.
      $threshold = variable_get('wow_character_refresh_threshold');

      foreach ($characters as $cid => $character) {
          // Refresh the entity by calling the service.
        if ($character->lastFetched + $threshold < REQUEST_TIME) {
          wow_character_refresh($character);
        }
      }
    }

    parent::attachLoad($characters, $revision_id);
  }

  /**
   * @param WoWCharacter $entity
   * @param DatabaseTransaction $transactin
   *
   * @see EntityAPIController::save()
   */
  public function save($entity, DatabaseTransaction $transaction = NULL) {
    $transaction = isset($transaction) ? $transaction : db_transaction();
    // Load the stored entity, if any.
    if (!empty($entity->{$this->idKey}) && !isset($entity->original)) {
      // In order to properly work in case of name changes, load the original
      // entity using the id key if it is available.
      $entity->original = entity_load_unchanged($this->entityType, $entity->{$this->idKey});
    }

    // We are about to set main status of a character.
    if ((!empty($entity->is_new) && $entity->isMain)
      || !empty($entity->original) && $entity->isMain != $entity->original->isMain) {

      // Invokes set_main hook on behalf the wow_character entity. Modules
      // implementers can check the entity and set the isMain property to FALSE.
      $this->invoke('set_main', $entity);

      // If the character is about to be main, update other to ensure unicity.
      if ($entity->isMain) {
        db_update('wow_characters')
          ->fields(array('isMain' => 0))
          ->condition('uid', $entity->uid)
          ->condition('cid', $entity->cid, '<>')
          ->execute();
      }
    }

    return parent::save($entity, $transaction);
  }
}
