<?php

/**
 * @file
 * Admin page callback file for the wow module.
 */

/**
 * Form builder; The API settings form.
 *
 * @ingroup forms
 * @see system_settings_form()
 */
function wow_admin_settings($form, &$form_state) {

  $form['authentication'] = array(
    '#type' => 'fieldset',
    '#title' => t('API Authentication'),
    '#description' => t("To send authenticated request you first need to register an application. Because registration isn't automated, application registration is limited to those who meet the following criteria:")
      . '<ul><li>' . t('You plan on making requests from one or more IP addresses (e.g. a production environment and development environment).') . '</li>'
      . '<li>' . t('You can justify making more than 2,000 requests per day from one or more IP addresses.') . '</li></ul>',
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );

  $ssl = extension_loaded('openssl');
  if (!$ssl) {
    $form['authentication']['#description'] .= '<strong class="error">' . t('Your PHP installation does not have SSL support enabled. Authentication has been disabled.') . '</strong>';
  }
  $form['authentication']['wow_key'] = array(
    '#type' => 'textfield',
    '#title' => t('Private Key'),
    '#attributes' => array('autocomplete' => 'off'),
    '#default_value' => variable_get('wow_key', ''),
    '#disabled' => !$ssl
  );
  $form['authentication']['wow_public_key'] = array(
    '#type' => 'textfield',
    '#title' => t('Public Key'),
    '#default_value' => variable_get('wow_public_key', ''),
    '#disabled' => !$ssl
  );

  return system_settings_form($form);
}

/**
 * Helper function to populate the locale dropdown.
 *
 * @deprecated: Use wow_api_info($region, 'locales') instead.
 */
function wow_locale_dropdown_options($region) {
  $locales = array_values(wow_api_info($region, 'locales'));
  return drupal_map_assoc($locales);
}

/**
 * Helper function to populate the realm dropdown. This call the battle.net API.
 *
 * @deprecated: Use wow_realm_textfield instead.
 */
function wow_realm_dropdown_options($region = NULL) {
  if (is_null($region)) {
    $region = variable_get('wow_region_default');
  }

  if ($cache = cache_get('wow_realms:' . $region)) {
    $realms = $cache->data;
  }
  else {
    // TODO: use database values instead.
    $response = wow_realm_fetch($region);

    foreach ($response->realms as $realm) {
      $realms[$realm->name] = $realm->name;
    }

    cache_set('wow_realms:' . $region, $realms, 'cache', CACHE_TEMPORARY);
  }

  return $realms;
}

/**
 * @deprecated: Use wow_api_info(NULL, 'name') instead.
 *
 * Return the wow regions supported by the API.
 */
function wow_region_options() {
  $regions = array();

  foreach (wow_api_info() as $region => $info) {
    $regions[$region] = $info->name;
  }

  return $regions;
}

/**
 * Menu callback; Displays wow admin dashboard.
 */
function wow_admin() {
  return '';
}
